bl_info = {
    "name": "Roblox Character Import",
    "author": "@nicolinooat",
    "version": (1, 0),
    "blender": (2, 80, 0),
    "location": "View3D > Add > Mesh > Roblox Character",
    "description": "Adds a new Roblox Character",
    "warning": "",
    "doc_url": "",
    "category": "Add Mesh",
}

import bpy
import requests
import zipfile
import io
import os
import mathutils
from bpy.types import Operator
from bpy.props import FloatVectorProperty
from bpy_extras.object_utils import AddObjectHelper, object_data_add
from mathutils import Vector
from bpy.props import (StringProperty,
                       PointerProperty,
                       )
from bpy.types import (Panel,
                       PropertyGroup,
                       )


def add_object(self, context):
    # bpy.data.is_saved
    mytool = context.scene.my_tool
    username = mytool.username
    url = "https://tools.nicolinoo.xyz/tools/roblox/character-downloader/download?user=%s" % username
    path = bpy.path.abspath("//Character_") + username

    if path == "Character_" + username:
        path = bpy.app.tempdir + "\\Character_" + username

    if not os.path.exists(path):
        os.makedirs(path)

    r = requests.get(url, allow_redirects=True)
    if not r or not r.content:
        return

    f = io.BytesIO(r.content)

    archive = zipfile.ZipFile(f, "r")
    archive.extractall(path)

    imported_obj = bpy.ops.import_scene.obj(filepath=path + ("/%s.obj" % username))
    object = bpy.context.selected_objects[0]

    object.location = mathutils.Vector((-0.17, 0.0, -99.80))


class OBJECT_OT_add_object(Operator, AddObjectHelper):
    """Create a new Mesh Object"""
    bl_idname = "mesh.add_character"
    bl_label = "Add Roblox Character"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        add_object(self, context)

        return {'FINISHED'}


class MyProperties(PropertyGroup):
    username: StringProperty(
        name="Username",
        description="Username of the character to import",
        default="nicolinooAT",
        maxlen=100,
    )


class OBJECT_PT_CustomPanel(Panel):
    bl_label = "Create Roblox User"
    bl_idname = "OBJECT_PT_custom_panel"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_category = "Tools"
    bl_context = "objectmode"

    @classmethod
    def poll(self, context):
        return context.object is not None

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        mytool = scene.my_tool

        layout.prop(mytool, "username")
        layout.separator()


# Registration

def add_object_button(self, context):
    self.layout.operator(
        OBJECT_OT_add_object.bl_idname,
        text="Add Character",
        icon='PLUGIN')


def register():
    bpy.utils.register_class(OBJECT_OT_add_object)
    bpy.utils.register_class(MyProperties)
    bpy.utils.register_class(OBJECT_PT_CustomPanel)
    bpy.types.VIEW3D_MT_mesh_add.append(add_object_button)

    bpy.types.Scene.my_tool = PointerProperty(type=MyProperties)


def unregister():
    bpy.utils.unregister_class(OBJECT_OT_add_object)
    bpy.utils.unregister_class(MyProperties)
    bpy.utils.unregister_class(OBJECT_PT_CustomPanel)
    bpy.types.VIEW3D_MT_mesh_add.remove(add_object_button)

    del bpy.types.Scene.my_tool


if __name__ == "__main__":
    register()
